<?php
/*
  Copyright (C) 2006-2008 Vladislav Staroselskiy (inet@vladstar.com)
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

  // === SETTINGS SECTION === //

  // -----------------------
  // PHP runtime parameters:
  // -----------------------

  // Set memory limit higher than default (8M) to handle bigger images
  // You may need to adjust it according to size of your images, in case
  // if you get errors. GD library takes a lot of your RAM...
  ini_set("memory_limit","60M");

  // Maximum execution time for this PHP script (default was 30 seconds). 
  // Sometimes, if you have hundreds of files in the same folder, 
  // it may take a while to create all thumbnails (especially if your web 
  // server is not powerful enough, so you can reach this timeout. 
  // Don't try to make it much higher - internet browsers usually have their 
  // own 3-5 minutes timeouts, unless you run this script from command prompt. 
  // If you get "Maximum execution time of NN seconds exceeded " - there is 
  // only way to go is to split files into few separate folders or 
  // upgrade your server's hardware. Sorry, no free lunch here.
  ini_set("max_execution_time","180");

  // ----------------------
  // Folders and filenames:
  // ----------------------

  // Directory with your photos, relative to the folder where script resides
  // Give your web server read-only permissions to it
  // Don't give write permissions, if you consider it as a backup
  $picture_folder="photos/";

  // Directory with your thumbnails, relative to this folder
  // keep it out of your photo folder and give appropriate read-write access 
  // to user account, that your web server runs from.
  $thumbnail_folder="thumbnails/";

  // Folder for temporary files, relative to this folder
  // Your web server must also have read-write permissions to it.
  $temp_folder="temp/";

  // Name of file, containing picture descriptions:
  // <filename1> <description1>
  // <filename2> <description2>
  // ... etc.
  $description_file="pictures.nfo";

  // Name of file, containing folder descriptions,
  // that will be used instead of folder names in a main menu:
  // <folder1> <description1>
  // <folder2> <description2>
  $folder_description_file="folders.nfo";

  // Name of lock file, it prevents simultaneous thumbnail generation
  // for the same folder by multiple users
  // It is automaticaly deleted after max_execution_time period is out
  $lock_file=".lock";

  // Name of info file, that will store file sizes
  // We'll use it as trigger to track changes in a folder
  $info_filename=".info";

  // Order of folders and subfolders in a main menu
  $folders_order="reverse"; // forward, reverse
  $subfolders_order="reverse"; // forward, reverse

  // Access mode for new folders, created by this script.
  // Don't be a maniac, make sure web server still has r/w access there.
  $new_folder_mode=0775;

  // Let everyone know about new photos by placing this image next to folder name
  // If doesn't exist we'll simply put "NEW" word instead
  $new_folder_sign="new.gif"; // path is relative to this folder

  // For how many days we'll consider folder with photos as a "New"
  // "0" will disable notification at all
  $new_folder_days=14;

  // How much time we keep files in a temp folder
  $temp_files_TTL="600"; // in seconds

  // Check folders structure for discrepancy on exit
  $check_folders_structure=true;

  // Defined CSS Style
  $style="photoalbum";

  // ------------------------
  // Pictures and thumbnails:
  // ------------------------

  // Thumbnails parameters:
  $thumbnail_max_width=0; // Maximum width of thimbnail, in pixels
  $thumbnail_max_height=130; // Maximum height of thimbnail, in pixels
  $thumbnail_quality=90; // Thumbnail JPEG quality, 0-100
  $thumbnail_border_size=5; // size of border for thumbnail of chosen picture

  // Quality of image, resized on server side
  // Feature for someone with slow connection or pay-per-Mb provider
  $resized_image_quality=75;  // Resized JPEG quality, 0-100

  // Proposed list of resolutions (keep "x" between horizontal and vertical dimension)
  $list_of_resolutions=array("640x480","800x600","1024x768","1280x1024","1600x1200","3200x2400");

  // Photo resolution, that users will see by default
  $default_resolution=800;

  // Maximum photo resolution, that users may request
  // Otherwise it may heavily load your server's engine
  $maximum_resolution=3200;

  // Variable, that determines whether maximum or minimum resolution size
  // should be taken as a basis when resizing an image on server side
  // For example, resizing 1024x1024 image down to 800x600 resolution 
  // in less restrictive mode will give 800x800 image, in more restrictive - 600x600
  $less_restrictive=false; // true, false

  // Whether allow to blow up the image resolution or not
  // (think about quality of small thumbnail increased by 10 times)
  $allow_resolution_increase=false;

  // Picture position on a screen, relative to thumbnails
  // (when "left" or "right" is chosen, thumbnails will surround it)
  $picture_position="top"; // top, bottom, left, right, 

  // Show description above/below the picture
  // no description will be shown if contains anything else or commented out 
  $show_description="above"; // above, below

  // Show EXIF information, if available
  $show_exif="limited"; // full, limited, none

  // List of EXIF tags to show in a limited mode
  $limited_exif_info=array("FileName","DateTime","FileSize","Make","Model","ExposureTime","ApertureFNumber","DateTimeOriginal","FocalLength","LongFocalLength","ShortFocalLength","Flash","ISOSpeedRatings","CCDWidth","Compression","Software");

  // Method used to convert image while using GD library
  // resampling gives better quality, but really slow :(
  $gd_method="resample"; // resample, resize

  // If you want to restrict everyone from downloading original images,
  // but resized only, change it to "true", then go to "photos" folder 
  // and rename .htaccess.disabled into .htaccess
  $disable_client_mode=false; // true, false

  // -------------------------------
  // Text on top of resized picture:
  // -------------------------------

  // Superimpose a custom text over resized images or not
  $write_text=true; // true, false

  // Text parameters for both "ttf" and "system" modes:
  $text_string="Powered by VStarPhotoAlbum";
  $text_position="top"; // top, bottom
  $text_x_margin=10; // Margin from the X (left) edge
  $text_y_margin=20; // Margin from the Y (top or bottom) edge
  $text_color_red="205"; // 0-255
  $text_color_green="205"; // 0-255
  $text_color_blue="205"; // 0-255
  $text_shadow=true;
  $text_ttf_font="fonts/Vera.ttf"; // Name of TrueType font
  $text_ttf_angle=0; // 0-360, counter-clockwise from left-to-right=0
  $text_ttf_size=8; // Text font size, usually from 6 to 72

  // List of authenticated users or IP addresses, that are allowed 
  // to add/edit picture descriptions through web interface
  // I don't think you want to allow everyone to edit your descriptions...
  $allowed_users=array("me","andy");
  $allowed_ip=array("192.168.1.1","192.168.1.2","192.168.1.3");
?>
